@@ -11,7 +11,7 @@ use MooX::Types::MooseLike::Base qw(:all);
 use PDF::Table;
 use PDF::TextBlock;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 NAME
 
@@ -632,6 +632,9 @@ sub text
         if ($string_before eq $string)
         {
             carp "Unable to fit text onto line: $string";
+            # If no more breaks then skip
+            last if $string !~ /\s/;
+            # Otherwise start from after next break
             $string =~ s/\S+\s//;
             $tb->text($string);
             ($endw, $ypos, $string) = $tb->apply;
